jactorch.nn
===========

.. automodule:: jactorch.nn

   
   
   

   
   
   

   
   
   

   
   
   



.. rubric:: Submodules
.. autosummary::
   :toctree:
   :template: base.rst
   :recursive:

   cnn
   container
   embedding
   functional
   gumbel_softmax
   linear
   losses
   neural_logic
   normalization
   probability
   prroi_pool
   quickaccess
   residual
   rnn_layers
   rnn_utils
   simple
   sync_batchnorm
   word_embedding









